@@ -1,4 +1,5 @@
-from volsite_postgres_common.api.CA import CA
+
+from volworld_aws_api_common.api.AA import AA
 
 URL_ROOT = "https://1b00ie0b72.execute-api.ap-northeast-1.amazonaws.com/prod"
 
@@ -7,7 +8,7 @@ def build_api_root_url(*elms) -> str:
     es = list()
     for e in elms:
         es.append(e)
-    return f"{URL_ROOT}/{CA.Api}/{'/'.join(es)}"
+    return f"{URL_ROOT}/{AA.Api}/{'/'.join(es)}"
     # return URL_ROOT + '/' + '/'.join(es)
 
 
